
#include "ClientUserJavaAdapter.h"

#include "clientuser_jni.h"

/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nNewInstance
 * Signature: ()J
 */
JNIEXPORT jlong JNICALL Java_com_perforce_client_api_ClientUser_nNewInstance
	(JNIEnv * env, jobject jJavaPeer)
{
	return (jlong)new ClientUserJavaAdapter( env, jJavaPeer );
}


/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nReleaseNativeGlobalRef
 * Signature: (J)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nReleaseNativeGlobalRef
	(JNIEnv * env, jclass, jlong jRef)
{
	ClientUserJavaAdapter * ref = (ClientUserJavaAdapter *)jRef;
	ref->ReleaseGlobalRef( env );
}

/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nDeleteInstance
 * Signature: (J)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nDeleteInstance
	(JNIEnv *, jclass, jlong jRef)
{
	delete (ClientUserJavaAdapter *)jRef;
}

/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nEdit
 * Signature: (JJJ)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nEdit
	(JNIEnv *, jclass, jlong jRef, jlong jFileSys, jlong jError)
{
	ClientUserJavaAdapter * ref = (ClientUserJavaAdapter *)jRef;
	FileSys * filesysRef = (FileSys *)jFileSys;
	Error * errorRef = (Error *)jError;
	
	ref->InheritedEdit( filesysRef, errorRef );
}

/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nDiff
 * Signature: (JJJZLjava/lang/String;J)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nDiff
	(JNIEnv * env, jclass, jlong jRef, jlong jFileSys1, jlong jFileSys2, jboolean doPage, jstring jDiffFlags, jlong jError)
{
	ClientUserJavaAdapter * ref = (ClientUserJavaAdapter *)jRef;
	FileSys * filesys1Ref = (FileSys *)jFileSys1;
	FileSys * filesys2Ref = (FileSys *)jFileSys2;
	Error * errorRef = (Error *)jError;
	
	char * cDiffFlags = (char *) env->GetStringUTFChars(jDiffFlags, NULL);
	
	ref->InheritedDiff(filesys1Ref, filesys2Ref, doPage, cDiffFlags, errorRef );
	
	env->ReleaseStringUTFChars(jDiffFlags, cDiffFlags);
	
}


/*
 * Class:     com_perforce_client_api_ClientUser
 * Method:    nMerge
 * Signature: (JJJJJJ)V
 */
JNIEXPORT void JNICALL Java_com_perforce_client_api_ClientUser_nMerge
	(JNIEnv *env, jclass, jlong jRef, jlong jBase, jlong jLeg1, jlong jLeg2, jlong jResult, jlong jE)
{
	ClientUserJavaAdapter * ref = (ClientUserJavaAdapter *)jRef;
	FileSys * base = (FileSys *)jBase;
	FileSys * leg1 = (FileSys *)jLeg1;
	FileSys * leg2 = (FileSys *)jLeg2;
	FileSys * result = (FileSys *)jResult;
	Error * e = (Error *)jE;
	
	ref->Merge(base, leg1, leg2, result, e );
}
